<?php

namespace App\Http\Controllers;

use App\Http\Requests\SearchClienteRequest;
use App\Http\Requests\StoreClienteRequest;
use App\Http\Requests\UpdateClienteRequest;
use App\Http\Resources\ClienteResource;
use App\Http\Resources\PedidoResource;
use Illuminate\Http\Request;
use App\Models\Cliente;
use App\Models\OpcoesPagamento;
use App\Models\Pedido;
use App\Models\PedidoImplatacaoItem;
use App\Models\PedidoLoja;
use App\Models\PedidoLojaProduto;
use App\Models\PedidoLojaProdutoModulo;
use App\Models\Produto;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Throwable;

class PedidoController extends Controller
{
    public function index(Request $request)
    {
        $user = Auth::user();

        if ($user->id) {
            $search = $request->input('search') ?? ''; // Garante que $search seja uma string, mesmo que seja nulo



            if ($search !== '') {
                $pedidos = Pedido::where('APELIDO', 'like', '%' . $search . '%')->where('user_id', $user->id)->get();
            } else {
                $pedidos = Pedido::where('user_id', $user->id)->get();
            }
            return PedidoResource::collection($pedidos);
        }
    }

    public function store(Request $request)
    {

        try {

            DB::beginTransaction();
            $user = Auth::user();
            $body  = $request->all();
            $existsPedido = Pedido::where('APELIDO', $body['APELIDO'])->first();

            if ($existsPedido) {
                return response()->json([
                    'message' => 'Este um pedido com o apelido "' . $body['APELIDO'] . '" já está cadastrado no sistema!'
                ], 401);
            }


            $body['user_id'] = $user->id;
            $body['OBSERVACAO_CONVERSAO'] =  $body['OBSERVACAO_CONVERSAO'] ?  $body['OBSERVACAO_CONVERSAO'] :  "Sem observações.";


            $pedido = Pedido::create($body);



            if ($body['lojas']) {
                foreach ($body['lojas'] as $key => $loja) {

                    $loja['PEDIDO_ID'] = $pedido->id;
                    $lojaCreate = PedidoLoja::create($loja);

                    if ($loja['produtos']) {
                        foreach ($loja['produtos'] as $keyProduto => $produto) {

                            $produto['PEDIDO_LOJA_ID'] = $lojaCreate->id;



                            $produtoLojaCreate = PedidoLojaProduto::create($produto);



                            if ($produto['modulos']) {
                                foreach ($produto['modulos'] as $keyModulos => $modulo) {

                                    $modulo['PEDIDO_LOJA_PRODUTO_ID'] = $produtoLojaCreate->id;



                                    $modulo = PedidoLojaProdutoModulo::create($modulo);
                                }
                            }
                        }
                    }
                }
            }

            if ($body['items_implatacao']) {
                foreach ($body['items_implatacao'] as $key => $item) {
                    $item['PEDIDO_ID'] = $pedido->id;
                    PedidoImplatacaoItem::create($item);
                }
            }

            if ($body['opcoes_pagamento']) {
                foreach ($body['opcoes_pagamento'] as $key => $item) {
                    $item['PEDIDO_ID'] = $pedido->id;
                    OpcoesPagamento::create($item);
                }
            }

            DB::commit();

            return response()->json([
                'message' => 'Pedido cadastrado com sucesso!'
            ], 200);
        } catch (Throwable $e) {
            DB::rollback();

            return response()->json([
                'message' => 'Ocorreu um erro ao salvar o pedido: ' . $e->getMessage()
            ], 400);
        }
    }

    public function show($id)
    {
        $user = Auth::user();
        $pedido = Pedido::where('user_id', $user->id)->findOrFail($id);

        $lojas = PedidoLoja::where('PEDIDO_ID', $id)->get();

        foreach ($lojas as $key => $loja) {

            $loja['produtos'] = PedidoLojaProduto::where('PEDIDO_LOJA_ID', $loja->id)->get();

            $loja['cliente'] = Cliente::find($loja->CLIENTE_ID);

            foreach ($loja['produtos'] as $key => $produto) {

                $loja['produtos'][$key]['produto'] = Produto::find($produto->PRODUTO_ID);
                $loja['produtos'][$key]['modulos'] = PedidoLojaProdutoModulo::where('PEDIDO_LOJA_PRODUTO_ID', $produto->id)->get();
            }

            $lojas[$key] = $loja;
        }
        $pedido['lojas'] = $lojas;
        $pedido['items_implatacao'] = PedidoImplatacaoItem::where('PEDIDO_ID', $id)->get();
        $pedido['opcoes_pagamento'] = OpcoesPagamento::where('PEDIDO_ID', $id)->get();




        return $pedido;
    }

    public function update(Request $request, $id)
    {
        try {

            DB::beginTransaction();
            $user = Auth::user();
            $pedido = Pedido::where('user_id', $user->id)->findOrFail($id);
            $body  = $request->all();


            if (!$pedido) {
                return response()->json([
                    'message' => 'Pedido não existe'
                ], 401);
            }



            $body['OBSERVACAO_CONVERSAO'] =  $body['OBSERVACAO_CONVERSAO'] ?  $body['OBSERVACAO_CONVERSAO'] :  "Sem observações.";


            $pedido->update($body);


            PedidoLoja::where('PEDIDO_ID', $id)->delete();
            if ($body['lojas']) {
                foreach ($body['lojas'] as $key => $loja) {

                    $loja['PEDIDO_ID'] = $id;
                    $lojaCreate = PedidoLoja::create($loja);

                    if ($loja['produtos']) {
                        foreach ($loja['produtos'] as $keyProduto => $produto) {

                            $produto['PEDIDO_LOJA_ID'] = $lojaCreate->id;



                            $produtoLojaCreate = PedidoLojaProduto::create($produto);



                            if ($produto['modulos']) {
                                foreach ($produto['modulos'] as $keyModulos => $modulo) {

                                    $modulo['PEDIDO_LOJA_PRODUTO_ID'] = $produtoLojaCreate->id;



                                    $modulo = PedidoLojaProdutoModulo::create($modulo);
                                }
                            }
                        }
                    }
                }
            }

            if ($body['items_implatacao']) {
                foreach ($body['items_implatacao'] as $key => $item) {
                    $item['PEDIDO_ID'] = $pedido->id;
                    PedidoImplatacaoItem::create($item);
                }
            }

            if ($body['opcoes_pagamento']) {

                OpcoesPagamento::where('PEDIDO_ID', $id)->delete();
                foreach ($body['opcoes_pagamento'] as $key => $item) {
                    $item['PEDIDO_ID'] = $pedido->id;
                    OpcoesPagamento::create($item);
                }
            }

            DB::commit();

            return response()->json([
                'message' => 'Pedido cadastrado com sucesso!'
            ], 200);
        } catch (Throwable $e) {
            DB::rollback();

            return response()->json([
                'message' => 'Ocorreu um erro ao salvar o pedido: ' . $e->getMessage()
            ], 400);
        }
    }

    public function destroy($id)
    {
        $pedido = Pedido::findOrFail($id);

        $pedido->delete();

        return response()->json([
            'message' => 'Pedido deletado com sucesso!'
        ], 200);
    }
}
