<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreRevendaRequest;
use App\Http\Requests\UpdateRevendaRequest;
use App\Http\Resources\RevendaResource;
use App\Models\Revenda;
use Illuminate\Support\Facades\Auth;

class RevendaController extends Controller
{
    public function index()
    {
        $user = Auth::user();
        $revendas = Revenda::where('user_id', $user->id)->get();

        return RevendaResource::collection($revendas);
    }

    public function store(StoreRevendaRequest $request)
    {
        $user = Auth::user();

        $existsCnpj = Revenda::where('CNPJ', $request->input('CNPJ'))->first();

        if ($existsCnpj) {
            return response()->json([
                'message' => 'Este CNPJ já está cadastrado no sistema!'
            ], 401);
        }

        $data = $request->validated();
        $data['user_id'] = $user->id;

        Revenda::create($data);

        return response()->json([
            'message' => 'Revenda cadastrada com sucesso!'
        ], 200);
    }

    public function show($id)
    {
        $user = Auth::user();
        $revenda = Revenda::where('user_id', $user->id)->findOrFail($id);

        return $revenda;
    }

    public function update(UpdateRevendaRequest $request, $id)
    {
        $user = Auth::user();
        $data = $request->validated();

        $revenda = Revenda::where('user_id', $user->id)
            ->where('id', $id)
            ->firstOrFail();

        $existsCnpj = Revenda::where('CNPJ', $data['CNPJ'])->where('id', '!=', $revenda->id)->first();
        if ($existsCnpj) {
            return response()->json([
                'message' => 'Já existe uma revenda com o CNPJ informado!'
            ], 401);
        }

        $revenda->update($data);

        return response()->json([
            'message' => 'Revenda atualizada com sucesso!'
        ], 200);
    }

    public function destroy($id)
    {
        $user = Auth::user();

        $revenda = Revenda::where('user_id', $user->id)
        ->findOrFail($id);

        $revenda->delete();

        return response()->json([
            'message' => 'Revenda deletada com sucesso!'
        ], 200);
    }
}
